<p align="center">
<img width="300" height="300" src="https://user-images.githubusercontent.com/61446372/228822639-f126e6a3-5bcb-4e04-80ed-1cb6325314bf.png" />
</p>

<h1 align="center">냥랭</h1>
<h2 align="center">세상에서 가장 귀여운 언어</h2>
<p align="center">
냥렝은 2023년에 Brainfxxk으로부터 파생되어, 세상에서 가장 귀여운 언어를 목표로 작업중에 있다냥.  
</p>
<h3 align="center"><a href="https://nyan.sserve.work">공식 웹사이트</a>에서 문서를 확인해보라냥.</h3>